Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( // ErrSecretNotFound represents the specified secret does not exist ErrSecretNotFound = xerrors.Errorf("secret is not found") // ErrKeyNotFound represents the specified key does not exist in the secret ErrKeyNotFound = xerrors.Errorf("key is not found in the secret") )
Functions ¶
This section is empty.
Types ¶
type GitHubAppInterface ¶
type GitHubAppInterface interface {
// GetURL returns https://github.com or GHE url
GetURL() string
// GetAppID returns app id for GitHub App
GetAppID() int64
// GetPrivateKey returns the raw private key for GitHub App
GetPrivateKey(ctx context.Context, c client.Client) ([]byte, error)
}
GitHubAppInterface is an interface for GitHub App
Click to show internal directories.
Click to hide internal directories.